@@ -1,5 +1,5 @@
 # prime/engine/engine-basic.rb
-# $Id: engine-userdict.rb,v 1.10 2004/05/31 05:27:33 komatsu Exp $
+# $Id: engine-userdict.rb,v 1.11 2004/12/09 12:24:15 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -260,8 +260,7 @@ class PrimeEngineUserdict < PrimeEngine
       (key, value) = item.split(/=/)
       data[key] = value
     }
-    word = PrimeWord.new(pron, literal, pos, score,
-                         data['category'], data['annotation'], data_list)
+    word = PrimeWord.new(pron, literal, pos, score, data)
   end
 
   def check_existence (pron, literal, pos)
