@@ -1,5 +1,5 @@
 # dictformat-cannadic.rb: Converter module for cannadic format.
-# $Id: dictformat-cannadic.rb,v 1.1.2.2 2003/12/29 09:50:35 komatsu Exp $
+# $Id: dictformat-cannadic.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -20,8 +20,8 @@ class DictFormatCannadic < DictFormat
                            PRIME_DATA_DIR + "/makedict/canna2prime.table")
     @pos_table = {}
     File::open(filename_postable, "r").each {|line|
-      (pos_prime, pos_canna) = line.chomp.split(/\t/)
-      @pos_table[pos_canna] = pos_prime
+      (pos_prime, pos_canna, *comment) = line.chomp.split(/\t/)
+      @pos_table[pos_canna] = pos_prime unless pos_prime =~ /^\#/
     }
   end
 
