@@ -1,5 +1,5 @@
 # dictformat-skk.rb: Converter module for skk format.
-# $Id: dictformat-skkdic.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
+# $Id: dictformat-skkdic.rb,v 1.3 2004/12/11 07:53:01 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -29,7 +29,8 @@ class DictFormatSkkdic < DictFormat
     words.each{|word|
       if valid_word?(pron, word) then
 	(literal, attr) = word.split(';')
-	results << [pron, @default_pos, literal, @default_freq, attr]
+        comment = "comment=#{attr}"
+	results << [pron, @default_pos, literal, @default_freq, comment]
       end
     }
     return results
