@@ -1,5 +1,5 @@
 # dictformat-cannadic.rb: Converter module for cannadic format.
-# $Id: dictformat.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
+# $Id: dictformat.rb,v 1.3 2004/04/29 21:35:54 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -104,10 +104,9 @@ class DictFormat
     pos = (pos1 or pos2)
 
     freq = (freq1.to_i or 0)
-    attr = attr2 + attr1
+    attr = (attr2 + attr1).uniq
     if pos1 == pos2 or pos1.nil? or pos2.nil? then
       freq  = [freq, freq2].max
-      attr += attr2
     end
 
     @dict[0][label(pron, pos, literal)] = [pron, pos, literal, freq, *attr]
