@@ -1,5 +1,5 @@
 #### prime-userdict.rb: Library for userdict of PRIME.
-#### $Id: userdict.rb,v 1.2 2004/03/25 17:19:51 komatsu Exp $
+#### $Id: userdict.rb,v 1.3 2004/05/31 05:27:33 komatsu Exp $
 ####
 #### Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 ####     All rights reserved.
@@ -137,7 +137,9 @@ class PrimeUserdictUpdate < PrimeUserdict
 
   def check_necessity (input_dict)
 #    if File::size(input_dict) == 0 or File::size(input_dict + '-co') == 0 then
-    if File::size(input_dict) == 0 and File::size(input_dict + '-co') == 0 then
+    if File::exist?(@output_file) and
+        File::size(input_dict) == 0 and
+        File::size(input_dict + '-co') == 0 then
       return false
     else
       return true
