@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.15 2004/12/15 14:12:58 komatsu Exp $
+# $Id: prime.rb,v 1.16 2004/12/16 14:44:09 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -314,7 +314,14 @@ class Prime
 #                                             words_uniclause)
 
 
-    words_compact = words[0,1]
+    ## Ruby 1.6 does not keep the class PrimeWordList word[0,1] if the
+    ## value of word is [], and the class of the result of word[0,1]
+    ## becomes Array which is a super class of PrimewordList.
+    if words.empty? then
+      words_compact = PrimeWordList.new()
+    else      
+      words_compact = words[0,1]
+    end
 
     if words_compact.length > 0 then
       predict_with_multi_clauses!(words_compact)
